Posterior Distance Distributions (`ligo.skymap.distance`)
=========================================================

.. automodule:: ligo.skymap.distance

Conditional Distributions
-------------------------

.. autosummary::

    conditional_pdf
    conditional_cdf
    conditional_ppf

.. autofunction:: conditional_pdf
.. autofunction:: conditional_cdf
.. autofunction:: conditional_ppf

Moments
-------

.. autosummary::

    moments_to_parameters
    parameters_to_moments
    parameters_to_marginal_moments

.. autofunction:: moments_to_parameters
.. autofunction:: parameters_to_moments
.. autofunction:: parameters_to_marginal_moments

Marginal Distributions
----------------------

.. autosummary::

    marginal_pdf
    marginal_cdf
    marginal_ppf

.. autofunction:: marginal_pdf
.. autofunction:: marginal_cdf
.. autofunction:: marginal_ppf

Kernel Density Estimation
-------------------------

.. autosummary::

    conditional_kde
    cartesian_kde_to_moments

.. autofunction:: conditional_kde
.. autofunction:: cartesian_kde_to_moments

Miscellaneous
-------------

.. autosummary::

    ud_grade
    volume_render
    principal_axes

.. autofunction:: ud_grade
.. autofunction:: volume_render
.. autofunction:: principal_axes
